/*
 * Click nbfs://nbhost/SystemFileSystem/Templates/Licenses/license-default.txt to change this license
 * Click nbfs://nbhost/SystemFileSystem/Templates/UnitTests/JUnit5TestClass.java to edit this template
 */
package com.jcg.selenium.alerts.popups;

import io.github.bonigarcia.wdm.WebDriverManager;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.openqa.selenium.Alert;
import org.openqa.selenium.By;
import org.openqa.selenium.WebDriver;
import org.openqa.selenium.chrome.ChromeDriver;
import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertTrue;
import org.openqa.selenium.JavascriptExecutor;
import org.openqa.selenium.WebElement;
import org.openqa.selenium.support.ui.ExpectedConditions;
import org.openqa.selenium.support.ui.WebDriverWait;
import java.time.Duration;

/**
 *
 * @author omozegieaziegbe
 */
public class SeleniumAlertsPopupsTest {

    private WebDriver driver;

    @BeforeEach
    public void setup() {
        WebDriverManager.chromedriver().setup();
        driver = new ChromeDriver();
        driver.manage().deleteAllCookies();
        driver.get("file:///Users/omozegieaziegbe/Development/selenium-alerts-popups/src/main/resources/popup-demo.html");
    }

    @Test
    public void handleSimpleAlert() {
        // Trigger the simple alert
        driver.findElement(By.id("simpleAlertButton")).click();

        // Handle the alert
        Alert alert = driver.switchTo().alert();
        String alertText = alert.getText();
        alert.accept();
        assertEquals("This is a simple alert!", alertText);
    }

    @Test
    public void handleConfirmationAlert() {
        WebElement element = driver.findElement(By.id("confirmAlertButton"));

        // Trigger the confirmation alert using JavascriptExecutor
        ((JavascriptExecutor) driver).executeScript("arguments[0].click()", element);

        // Switch to the alert and get its text
        Alert confirmationAlert = driver.switchTo().alert();
        String alertText = confirmationAlert.getText();

        // Assert the alert text
        Assertions.assertEquals("Do you confirm this action?", alertText);

        // Accept the alert (click OK)
        confirmationAlert.accept();

        // Verify the message displayed after accepting the alert
        String confirmationMessage = driver.findElement(By.id("confirmationMessage")).getText();
        Assertions.assertEquals("You clicked OK!", confirmationMessage);

        driver.findElement(By.id("confirmAlertButton")).click();
        confirmationAlert = driver.switchTo().alert();
        confirmationAlert.dismiss();

        String cancelMessage = driver.findElement(By.id("confirmationMessage")).getText();
        Assertions.assertEquals("You clicked Cancel!", cancelMessage);
    }

    @Test
    public void handlePromptAlert() {

        WebElement element = driver.findElement(By.id("promptAlertButton"));

        ((JavascriptExecutor) driver).executeScript("arguments[0].click()", element);

        Alert promptAlert = driver.switchTo().alert();

        String alertText = promptAlert.getText();
        Assertions.assertEquals("Please enter your name:", alertText);
        promptAlert.sendKeys("Test User");
        promptAlert.accept();

        // Verify the message displayed after interacting with the prompt
        String confirmationMessage = driver.findElement(By.id("promptMessage")).getText();
        Assertions.assertEquals("Hello Test User! How are you today?", confirmationMessage);
    }

    @Test
    public void handleDialogBoxes() {
        // Click the "Open Dialog" button to make the dialog visible
        WebElement openDialogButton = driver.findElement(By.xpath("//button[text()='Open Dialog']"));
        openDialogButton.click();

        // Wait for the dialog to appear
        WebDriverWait wait = new WebDriverWait(driver, Duration.ofSeconds(10), Duration.ofMillis(500));
        WebElement dialog = wait.until(ExpectedConditions.visibilityOfElementLocated(By.id("dialog")));

        // Locate and click the "Close" button in the dialog
        WebElement closeButton = driver.findElement(By.id("closeModal"));
        closeButton.click();

        // Wait until the dialog is closed
        boolean isDialogClosed = wait.until(ExpectedConditions.invisibilityOf(dialog));

        // Verify the dialog is closed
        assertTrue(isDialogClosed, "The dialog should be closed after clicking the close button");
    }


}
